fn recommend_users_prime_cache() -> Result<Vec<(u32, String)>, AppError>Expand description
Primes the cached function recommend_users.
This is a cached function that uses the RECOMMEND_USERS cached static.
fn recommend_users_prime_cache() -> Result<Vec<(u32, String)>, AppError>Primes the cached function recommend_users.
This is a cached function that uses the RECOMMEND_USERS cached static.